<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
<!DOCTYPE bugzilla SYSTEM "https://bugzilla.yoctoproject.org/page.cgi?id=bugzilla.dtd">

<bugzilla version="5.0.6"
          urlbase="https://bugzilla.yoctoproject.org/"
          
          maintainer="it-coreprojects-helpdesk@linuxfoundation.org"
>

    <bug>
          <bug_id>9962</bug_id>
          
          <creation_ts>2016-07-17 08:14:52 +0000</creation_ts>
          <short_desc>Suggested additions to the --help output re. -v and -D</short_desc>
          <delta_ts>2017-04-03 21:32:26 +0000</delta_ts>
          <reporter_accessible>1</reporter_accessible>
          <cclist_accessible>1</cclist_accessible>
          <classification_id>7</classification_id>
          <classification>Build System, Metadata &amp; Runtime</classification>
          <product>BitBake</product>
          <component>bitbake</component>
          <version>2.3</version>
          <rep_platform>x86</rep_platform>
          <op_sys>Multiple</op_sys>
          <bug_status>RESOLVED</bug_status>
          <resolution>FIXED</resolution>
          
          
          <bug_file_loc></bug_file_loc>
          <status_whiteboard></status_whiteboard>
          <keywords></keywords>
          <priority>Medium</priority>
          <bug_severity>enhancement</bug_severity>
          <target_milestone>2.3 M4</target_milestone>
          
          
          <everconfirmed>1</everconfirmed>
          <reporter>ulfalizer</reporter>
          <assigned_to name="Diana Thayer">garbados</assigned_to>
          <cc>brian.avery</cc>
    
    <cc>garbados</cc>
    
    <cc>libertad.gonzalez.de.la.cruz</cc>
    
    <cc>poky.bs.watcher</cc>
    
    <cc>poky.watcher</cc>
    
    <cc>ross.burton</cc>
    
    <cc>sgw</cc>
    
    <cc>srifenbark</cc>
          
          
          <cf_os>---</cf_os>
          <cf_regression_type>---</cf_regression_type>
          
          <cf_docchange>Done (doc changes complete)</cf_docchange>

      

      

      

          <comment_sort_order>oldest_to_newest</comment_sort_order>  
          <long_desc isprivate="0" >
    <commentid>64082</commentid>
    <comment_count>0</comment_count>
    <who name="">ulfalizer</who>
    <bug_when>2016-07-17 08:14:52 +0000</bug_when>
    <thetext>-v and -D aren&apos;t very well documented at the moment. I suggest changing the following,

       -v, --verbose         Output more log message data to the terminal.
       -D, --debug           Increase the debug level. You can specify this more
                             than once.

, to the following:

       -v, --verbose         Enable tracing of shell tasks (with &apos;set -x&apos;).
                             Also print bb.note(...) messages to stdout (in
                             addition to writing them to ${T}/log.do_&lt;task&gt;).
       -D, --debug           Increase the debug level. You can specify this
                             more than once. -D sets the debug level to 1,
                             where only bb.debug(1, ...) messages are printed
                             to stdout; -DD sets the debug level to 2, where
                             both bb.debug(1, ...) and bb.debug(2, ...)
                             messages are printed; etc. Without -D, no debug
                             messages are printed. Note that -D only affects
                             output to stdout. All debug messages are written
                             to ${T}/log.do_taskname, regardless of the debug
                             level.

See https://bugzilla.yoctoproject.org/show_bug.cgi?id=9950 as well, which prompted this ticket.</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>64301</commentid>
    <comment_count>1</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2016-07-21 19:23:59 +0000</bug_when>
    <thetext>This should probably not be assigned to me as it is the code that needs changing to produce the help output.  Once the code is changed and I can see it merged into poky, I will update the manual&apos;s example output section to match.

Scott</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>64325</commentid>
    <comment_count>2</comment_count>
    <who name="">ulfalizer</who>
    <bug_when>2016-07-22 07:49:54 +0000</bug_when>
    <thetext>One small self-nit: ${T}/log.do_taskname could be changed to ${T}/log.do_&lt;task&gt; to be consistent with the description for -v.</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>65837</commentid>
    <comment_count>3</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2016-09-06 18:53:28 +0000</bug_when>
    <thetext>Triage team... please assign this bug to someone else.  

Thanks, 
Scott</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>67556</commentid>
    <comment_count>4</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2016-10-25 20:10:33 +0000</bug_when>
    <thetext>Setting target to 2.3 M2 Just to get the bug off my back.  Someone else needs to own this bug.</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>68128</commentid>
    <comment_count>5</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2016-11-08 17:43:18 +0000</bug_when>
    <thetext>Bug Team... this bug should be re-assigned to someone that can change the --help code for BitBake.

Scott</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>70286</commentid>
    <comment_count>6</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2017-01-31 16:28:42 +0000</bug_when>
    <thetext>Not my bug - please assign to someone that can change the actual help output.  I am setting to &quot;Wait for Upstream&quot; when the actual code is changed.  Let me know when that happens and I will update the doc.

Scott</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71472</commentid>
    <comment_count>7</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2017-03-20 17:58:17 +0000</bug_when>
    <thetext>Setting to 2.3 M4.  This is not my bug.  Please change it to whoever updates the help output in the code.

Scott</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71618</commentid>
    <comment_count>8</comment_count>
    <who name="Diana Thayer">garbados</who>
    <bug_when>2017-03-23 02:30:12 +0000</bug_when>
    <thetext>Hello!

I grabbed this bug after submitting a patch for it. I grep&apos;d for the existing documentation, replaced it, and tried to match surrounding whitespace. I did my best to regard patch submission guidelines and code styleguides, but please let me know if there&apos;s anything I can do better in the future!

Diana</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71639</commentid>
    <comment_count>9</comment_count>
    <who name="brian avery">brian.avery</who>
    <bug_when>2017-03-23 14:38:32 +0000</bug_when>
    <thetext>I like this more verbose version. If I&apos;m doing a --help, I&apos;d just as soon have a more detailed version.</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71755</commentid>
    <comment_count>10</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2017-03-27 17:11:35 +0000</bug_when>
    <thetext>Hi, 

So I opened a new shell and did a &apos;git fetch origin&apos; for poky while in my local repo of poky.  Then, I did a &apos;bitbake -h&apos; command and the help I am getting is still the short version as output for -v and -D - 

  -v, --verbose         Output more log message data to the terminal.
  -D, --debug           Increase the debug level. You can specify this more
                        than once.

Is the change Diana indicated in Comment 8 in a different poky branch?  How do I see the final version of the help text for -v and -D?  

Thanks, 
Scott</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71770</commentid>
    <comment_count>11</comment_count>
    <who name="brian avery">brian.avery</who>
    <bug_when>2017-03-27 19:41:29 +0000</bug_when>
    <thetext>it hasn&apos;t been merged yet. patch is at : https://patchwork.openembedded.org/series/5911/#</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71776</commentid>
    <comment_count>12</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2017-03-27 20:56:44 +0000</bug_when>
    <thetext>Thanks Brian... will the patch be merged in time for 2.3?</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>71966</commentid>
    <comment_count>13</comment_count>
    <who name="Ross Burton">ross.burton</who>
    <bug_when>2017-03-31 14:40:49 +0000</bug_when>
    <thetext>Merged in Bitbake 921592026c69287cdb40ffd90944d5944f28e2c3.</thetext>
  </long_desc><long_desc isprivate="0" >
    <commentid>72051</commentid>
    <comment_count>14</comment_count>
    <who name="Scott Rifenbark">srifenbark</who>
    <bug_when>2017-04-03 21:32:26 +0000</bug_when>
    <thetext>Hi, 

The patch for the BitBake manual had an error in it.  It was using the &lt; and &gt; characters, which are illegal in DocBook causing the &quot;make&quot; to not work for the manual.  I have updated the file to use the &amp;lt; and &amp;gt; strings so the manual will compile.

I am marking the doc flag to &quot;done&quot; for this bug.

Thanks, 
Scott</thetext>
  </long_desc>
      
      

    </bug>

</bugzilla>